@@ -448,6 +448,7 @@ public:
 
         clearBuffers();
 
+        fInstance->enableAllBuses();
         fInstance->refreshParameterList();
 
         uint32_t aIns, aOuts, mIns, mOuts, params;
@@ -456,9 +457,9 @@ public:
         bool needsCtrlIn, needsCtrlOut;
         needsCtrlIn = needsCtrlOut = false;
 
-        aIns   = (fInstance->getTotalNumInputChannels() > 0)  ? static_cast<uint32_t>(fInstance->getTotalNumInputChannels())  : 0;
-        aOuts  = (fInstance->getTotalNumOutputChannels() > 0) ? static_cast<uint32_t>(fInstance->getTotalNumOutputChannels()) : 0;
-        params = (fInstance->getNumParameters() > 0)          ? static_cast<uint32_t>(fInstance->getNumParameters())          : 0;
+        aIns   = static_cast<uint32_t>(std::max(fInstance->getTotalNumInputChannels(), 0));
+        aOuts  = static_cast<uint32_t>(std::max(fInstance->getTotalNumOutputChannels(), 0));
+        params = static_cast<uint32_t>(std::max(fInstance->getNumParameters(), 0));
 
         if (fInstance->acceptsMidi())
         {
